@@ -9,7 +9,7 @@ use constant _share_dir => File::ShareDir::dist_dir('Alien-Libarchive');
 use constant _alien_libarchive019 => 1;
 
 # ABSTRACT: Build and make available libarchive
-our $VERSION = '0.18_06'; # VERSION
+our $VERSION = '0.20_01'; # VERSION
 
 my $cf = 'Alien::Libarchive::ConfigData';
 
@@ -74,14 +74,8 @@ sub dlls
   }
   else
   {
-    opendir(my $dh, _catdir(_share_dir, 'libarchive019', 'dll'));
-    @list = grep { ! -l $_ }
-            map { _catfile(_share_dir, 'libarchive019', 'dll', $_) }
-            grep { /\.so/ || /\.(dll|dylib)$/ }
-            grep !/^\./,
-            sort
-            readdir $dh;
-    closedir $dh;
+    @list = map { _catfile(_share_dir, 'libarchive019', 'dll', $_) }
+            @{ $cf->config("dlls") };
   }
   wantarray ? @list : $list[0];
 }
@@ -92,6 +86,18 @@ sub install_type
   $cf->config("install_type");
 }
 
+
+sub pkg_config_dir
+{
+  _catdir(_share_dir, 'libarchive019', 'lib', 'pkgconfig');
+}
+
+
+sub pkg_config_name
+{
+  'libarchive';
+}
+
 # extract the macros from the header files, this is a private function
 # because it may not be portable.  Used by the Archive::Libarchive::XS
 # build process (and maybe Archive::Libarchive::FFI) to automatically
@@ -142,7 +148,7 @@ Alien::Libarchive - Build and make available libarchive
 
 =head1 VERSION
 
-version 0.18_06
+version 0.20_01
 
 =head1 SYNOPSIS
 
@@ -277,6 +283,16 @@ Returns just the first dynamic library found in scalar context.
 
 Returns the install type, one of either C<system> or C<share>.
 
+=head2 pkg_config_dir
+
+Returns a path that contains the libarchive.pc file which can be used
+by pkg-config for linking against libarchive.
+
+=head2 pkg_config_name
+
+Returns the name by which pkg-config knows libarchive (should always
+be libarchive).
+
 =head1 CAVEATS
 
 Debian Linux and FreeBSD (9.0) have been tested the most
